package mop;

import mop.impl.SampleOutput;
import mop.impl.SampleSource;
import mop.impl.SampleTransformer;
import mop.pipe.Channel;
import mop.pipe.ChannelFactory;

/**
 * Main program.<p>
 * 
 * La parte principale dell'applicazione alloca un canale con nome "sample"
 * e registra i 4 componenti di esempio, nell'ordine:
 * <ul>
 *   <li>SampleSource: prima sorgente documento XML. 
 *                     Produce un documento DOM su da una stringa costante cablata
 *   <li>SampleOutput: visualizza su stdout il documento XML appena generato, non ancora modificato
 *   <li>SampleTransformer: applica una semplice trasformazione aggiungendo un attributo al documento DOM-XML
 *   <li>SampleOutput: visualizza su stdout il documento XML trasformato
 * <ul>
 */
public class Main {

    /**
     * @param args lista argomenti a linea di comando. Non utilizzato dall'aplicazione.
     */
    public static void main(String[] args) {
        try {
            // Alloca un canale di comunicazione con nome "sample" 
            Channel channel = ChannelFactory.getChannel("sample", true);
            
            // Registra nel canale di comunicazione il primo producer
            // documento DOM-XML
            channel.setSource(new SampleSource());
            channel.addListener(new SampleOutput());
            
            // Registra nel canale di comunicazione il trasformatore e mostra
            // il documento DOM-XML
            channel.addListener(new SampleTransformer());
            channel.addListener(new SampleOutput());
            
            // Esegue la catena di componeni registrati nel canale
            channel.process();
        } catch (Exception ex) {
            ex.printStackTrace();
        }
    }

}