package mop.pipe;

/**
 * Channel è il sistema di cumunicazione e coordinamento dei componenti per l'elaborazione 
 * delle informazioni XML.<p>
 * Channel prevede una prima fase di configurazione, dove è possibile registrare
 * una sorgente di dati XML (opzionale) e una lista di componenti per l'elaborazione delle 
 * infromazioni (DocumentListener).<br>
 * Una volta configurato il canale, tramite il metodo <i>process</i> sarà possibile innescare
 * la catena di trasformazioni dei vari componenti registrati.
 * 
 * @see mop.pipe.ChannelFactory    
 */
public interface Channel {
    /**
     * Identificativo canale. Solitamente i vari canali vengono identificati nella
     * factory tramite un identificativo di tipo stringa.
     * 
     * @return stringa con identificativo canale.
     */
    public abstract String getName();

    /**
     * Imposta la sorgente di default. Essendo la sorgente il primo componente di un canale,
     * è supporta solamente la registrazione di una singola sorgente dati, i sucessivi componenti
     * dovranno sempre elaborare anche le informazioni pervenute dal componente precedente. 
     * 
     * @param source sorgente DOM-XML
     * @see DocumentSource
     */
    public abstract void setSource(DocumentSource source);

    /**
     * Aggiunge un componente (listener) per l'elaborazione DOM-XML al canale.
     * I componenti registrati verranno poi richiamati in sequenza una volta invocato il metodo
     * <i>process</i> 
     * 
     * @param listener listener documento DOM-XML
     */
    public abstract void addListener(DocumentListener listener);

    /**
     * Rimuove un componente (listener) per elaborazione DOM-XML dal canale
     * 
     * @param listener
     */
    public abstract void removeListener(DocumentListener listener);

    /**
     * Richiama in sequenza la sorgente dati e tutti i componenti registrati per
     * l'elaborazione XML.
     * 
     * @throws ChannelException in caso di anomalie
     */
    public abstract void process() throws ChannelException;

    /**
     * Richiama in sequenza i componenti registrati tranne la sorgente ed labora l'XML
     * presente nell'evento <i>event</i>
     * 
     * @param event evento da elaborare
     * @throws ChannelException in caso di anomalie
     */
    public abstract void process(DocumentEvent event) throws ChannelException;
}